# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr
from empire_platform_api_public_client.models.address import Address
from empire_platform_api_public_client.models.organisation_status import OrganisationStatus
from empire_platform_api_public_client.models.organisation_type import OrganisationType
from empire_platform_api_public_client.models.participant_overview_data_contact_information import ParticipantOverviewDataContactInformation
from empire_platform_api_public_client.models.participant_overview_data_finance_overview import ParticipantOverviewDataFinanceOverview
from empire_platform_api_public_client.models.participant_overview_data_organisation_members import ParticipantOverviewDataOrganisationMembers

class ParticipantOverviewData(BaseModel):
    """
    ParticipantOverviewData
    """
    id: StrictStr = Field(..., description="Unique identifier for the record in UUID4 format")
    name: StrictStr = Field(...)
    type: OrganisationType = Field(...)
    status: OrganisationStatus = Field(...)
    billing_address: Address = Field(..., alias="billingAddress")
    finance_overview: ParticipantOverviewDataFinanceOverview = Field(..., alias="financeOverview")
    organisation_members: ParticipantOverviewDataOrganisationMembers = Field(..., alias="organisationMembers")
    contact_information: ParticipantOverviewDataContactInformation = Field(..., alias="contactInformation")
    __properties = ["id", "name", "type", "status", "billingAddress", "financeOverview", "organisationMembers", "contactInformation"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParticipantOverviewData:
        """Create an instance of ParticipantOverviewData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of billing_address
        if self.billing_address:
            _dict['billingAddress'] = self.billing_address.to_dict()
        # override the default output from pydantic by calling `to_dict()` of finance_overview
        if self.finance_overview:
            _dict['financeOverview'] = self.finance_overview.to_dict()
        # override the default output from pydantic by calling `to_dict()` of organisation_members
        if self.organisation_members:
            _dict['organisationMembers'] = self.organisation_members.to_dict()
        # override the default output from pydantic by calling `to_dict()` of contact_information
        if self.contact_information:
            _dict['contactInformation'] = self.contact_information.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParticipantOverviewData:
        """Create an instance of ParticipantOverviewData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ParticipantOverviewData.parse_obj(obj)

        _obj = ParticipantOverviewData.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "type": obj.get("type"),
            "status": obj.get("status"),
            "billing_address": Address.from_dict(obj.get("billingAddress")) if obj.get("billingAddress") is not None else None,
            "finance_overview": ParticipantOverviewDataFinanceOverview.from_dict(obj.get("financeOverview")) if obj.get("financeOverview") is not None else None,
            "organisation_members": ParticipantOverviewDataOrganisationMembers.from_dict(obj.get("organisationMembers")) if obj.get("organisationMembers") is not None else None,
            "contact_information": ParticipantOverviewDataContactInformation.from_dict(obj.get("contactInformation")) if obj.get("contactInformation") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AuditLogType(str, Enum):
    """
    AuditLogType
    """

    """
    allowed enum values
    """
    CREATE_LONG_TERM_AUCTION = 'CREATE_LONG_TERM_AUCTION'
    CREATE_DAY_AHEAD_AUCTION = 'CREATE_DAY_AHEAD_AUCTION'
    CREATE_INTRA_DAY_AUCTION = 'CREATE_INTRA_DAY_AUCTION'
    UPDATE_LONG_TERM_AUCTION = 'UPDATE_LONG_TERM_AUCTION'
    UPDATE_DAY_AHEAD_AUCTION = 'UPDATE_DAY_AHEAD_AUCTION'
    UPDATE_INTRA_DAY_AUCTION = 'UPDATE_INTRA_DAY_AUCTION'
    DELETE_AUCTION = 'DELETE_AUCTION'
    CANCEL_AUCTION = 'CANCEL_AUCTION'
    SUBMIT_LONG_TERM_BIDS = 'SUBMIT_LONG_TERM_BIDS'
    SUBMIT_DAY_AHEAD_OR_INTRA_DAY_BIDS = 'SUBMIT_DAY_AHEAD_OR_INTRA_DAY_BIDS'
    UPDATE_LONG_TERM_AUCTION_DEFAULT = 'UPDATE_LONG_TERM_AUCTION_DEFAULT'
    UPDATE_DAY_AHEAD_OR_INTRA_DAY_AUCTION_DEFAULT = 'UPDATE_DAY_AHEAD_OR_INTRA_DAY_AUCTION_DEFAULT'
    SUBMIT_NTC_OVERRIDE = 'SUBMIT_NTC_OVERRIDE'
    CREATE_NTC_REDUCTION = 'CREATE_NTC_REDUCTION'
    UPDATE_NTC_REDUCTION = 'UPDATE_NTC_REDUCTION'
    DELETE_NTC_REDUCTION = 'DELETE_NTC_REDUCTION'
    CREATE_NTC_ADDITION = 'CREATE_NTC_ADDITION'
    UPDATE_NTC_ADDITION = 'UPDATE_NTC_ADDITION'
    DELETE_NTC_ADDITION = 'DELETE_NTC_ADDITION'
    CREATE_UNPLANNED_OUTAGE = 'CREATE_UNPLANNED_OUTAGE'
    UPDATE_UNPLANNED_OUTAGE = 'UPDATE_UNPLANNED_OUTAGE'
    CANCEL_UNPLANNED_OUTAGE = 'CANCEL_UNPLANNED_OUTAGE'
    END_UNPLANNED_OUTAGE = 'END_UNPLANNED_OUTAGE'
    CREATE_PLANNED_OUTAGE = 'CREATE_PLANNED_OUTAGE'
    UPDATE_PLANNED_OUTAGE = 'UPDATE_PLANNED_OUTAGE'
    DELETE_PLANNED_OUTAGE = 'DELETE_PLANNED_OUTAGE'
    CANCEL_PLANNED_OUTAGE = 'CANCEL_PLANNED_OUTAGE'
    SUBMIT_TIMESCALE_NOMINATIONS = 'SUBMIT_TIMESCALE_NOMINATIONS'
    SUBMIT_SOSO_NOMINATIONS = 'SUBMIT_SOSO_NOMINATIONS'
    SUBMIT_BPP_NOMINATIONS = 'SUBMIT_BPP_NOMINATIONS'
    CREATE_LONG_TERM_DEFAULT_BID = 'CREATE_LONG_TERM_DEFAULT_BID'
    CREATE_DAY_AHEAD_OR_INTRA_DAY_DEFAULT_BID = 'CREATE_DAY_AHEAD_OR_INTRA_DAY_DEFAULT_BID'
    UPDATE_LONG_TERM_DEFAULT_BID = 'UPDATE_LONG_TERM_DEFAULT_BID'
    UPDATE_DAY_AHEAD_OR_INTRA_DAY_DEFAULT_BID = 'UPDATE_DAY_AHEAD_OR_INTRA_DAY_DEFAULT_BID'
    DELETE_DEFAULT_BID = 'DELETE_DEFAULT_BID'
    CREATE_DEFAULT_NOMINATION = 'CREATE_DEFAULT_NOMINATION'
    UPDATE_DEFAULT_NOMINATION = 'UPDATE_DEFAULT_NOMINATION'
    DELETE_DEFAULT_NOMINATION = 'DELETE_DEFAULT_NOMINATION'
    CREATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOW_OVERRIDE = 'CREATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOW_OVERRIDE'
    CREATE_INTRA_DAY_NOMINATION_WINDOW_OVERRIDE = 'CREATE_INTRA_DAY_NOMINATION_WINDOW_OVERRIDE'
    UPDATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOW_OVERRIDE = 'UPDATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOW_OVERRIDE'
    UPDATE_INTRA_DAY_NOMINATION_WINDOW_OVERRIDE = 'UPDATE_INTRA_DAY_NOMINATION_WINDOW_OVERRIDE'
    RESEND_CRISIS_REMIT = 'RESEND_CRISIS_REMIT'
    BYPASS_CRISIS_REMIT = 'BYPASS_CRISIS_REMIT'
    COMPLETE_CRISIS_STATIC_TASK = 'COMPLETE_CRISIS_STATIC_TASK'
    CANCEL_CRISIS_AUCTION = 'CANCEL_CRISIS_AUCTION'
    DISMISS_CRISIS_AUCTION = 'DISMISS_CRISIS_AUCTION'
    EXECUTE_CRISIS_CURTAILMENT = 'EXECUTE_CRISIS_CURTAILMENT'
    DISMISS_CRISIS_CURTAILMENT = 'DISMISS_CRISIS_CURTAILMENT'
    DISMISS_CRISIS_BPP = 'DISMISS_CRISIS_BPP'
    POST_CRISIS_PARTICIPANT_MESSAGE = 'POST_CRISIS_PARTICIPANT_MESSAGE'
    UPLOAD_ATTACHMENT = 'UPLOAD_ATTACHMENT'
    CREATE_PARTICIPANT_ORGANISATION = 'CREATE_PARTICIPANT_ORGANISATION'
    UPDATE_PARTICIPANT_ORGANISATION = 'UPDATE_PARTICIPANT_ORGANISATION'
    UPDATE_USER = 'UPDATE_USER'
    INVITE_USER = 'INVITE_USER'
    BULK_INVITE_USERS = 'BULK_INVITE_USERS'
    RESEND_USER_INVITE = 'RESEND_USER_INVITE'
    REVOKE_USER_INVITE = 'REVOKE_USER_INVITE'
    SUSPEND_USER = 'SUSPEND_USER'
    UNSUSPEND_USER = 'UNSUSPEND_USER'
    IMPERSONATE_USER = 'IMPERSONATE_USER'
    UPDATE_PROFILE_DETAILS = 'UPDATE_PROFILE_DETAILS'
    UPDATE_PREFERENCES = 'UPDATE_PREFERENCES'
    CREATE_API_KEY = 'CREATE_API_KEY'
    DELETE_API_KEY = 'DELETE_API_KEY'
    UPDATE_BIDDING_CONFIGURATION = 'UPDATE_BIDDING_CONFIGURATION'
    CREATE_ORGANISATION_DOCUMENT = 'CREATE_ORGANISATION_DOCUMENT'
    DELETE_ORGANISATION_DOCUMENT = 'DELETE_ORGANISATION_DOCUMENT'
    SUBMIT_BPP_PURCHASE_FORM = 'SUBMIT_BPP_PURCHASE_FORM'
    SET_BPP_SUBMISSION_STATUS = 'SET_BPP_SUBMISSION_STATUS'
    RESUBMIT_BPP_SUBMISSION = 'RESUBMIT_BPP_SUBMISSION'
    CREATE_DAY_AHEAD_BUY_NOW_OFFERS = 'CREATE_DAY_AHEAD_BUY_NOW_OFFERS'
    CREATE_INTRA_DAY_BUY_NOW_OFFERS = 'CREATE_INTRA_DAY_BUY_NOW_OFFERS'
    PURCHASE_BUY_NOW_OFFER = 'PURCHASE_BUY_NOW_OFFER'
    DELETE_BUY_NOW_OFFER = 'DELETE_BUY_NOW_OFFER'
    DELETE_DAY_AHEAD_BUY_NOW_OFFERS = 'DELETE_DAY_AHEAD_BUY_NOW_OFFERS'
    DELETE_INTRA_DAY_BUY_NOW_OFFERS = 'DELETE_INTRA_DAY_BUY_NOW_OFFERS'
    CREATE_SECONDARY_MARKET_RETURN_REQUEST = 'CREATE_SECONDARY_MARKET_RETURN_REQUEST'
    WITHDRAW_SECONDARY_MARKET_RETURN_REQUEST = 'WITHDRAW_SECONDARY_MARKET_RETURN_REQUEST'
    REJECT_SECONDARY_MARKET_TRANSFER_REQUEST = 'REJECT_SECONDARY_MARKET_TRANSFER_REQUEST'
    ACCEPT_SECONDARY_MARKET_TRANSFER_REQUEST = 'ACCEPT_SECONDARY_MARKET_TRANSFER_REQUEST'
    WITHDRAW_SECONDARY_MARKET_TRANSFER_REQUEST = 'WITHDRAW_SECONDARY_MARKET_TRANSFER_REQUEST'
    CREATE_LT_SECONDARY_MARKET_TRANSFER_REQUEST = 'CREATE_LT_SECONDARY_MARKET_TRANSFER_REQUEST'
    CREATE_DA_OR_ID_SECONDARY_MARKET_TRANSFER_REQUEST = 'CREATE_DA_OR_ID_SECONDARY_MARKET_TRANSFER_REQUEST'
    CREATE_LT_SECONDARY_MARKET_NOTICEBOARD_ENTRY = 'CREATE_LT_SECONDARY_MARKET_NOTICEBOARD_ENTRY'
    CREATE_DA_OR_ID_SECONDARY_MARKET_NOTICEBOARD_ENTRY = 'CREATE_DA_OR_ID_SECONDARY_MARKET_NOTICEBOARD_ENTRY'
    CREATE_LT_SECONDARY_MARKET_NOTICEBOARD_RESPONSE = 'CREATE_LT_SECONDARY_MARKET_NOTICEBOARD_RESPONSE'
    CREATE_DA_OR_ID_SECONDARY_MARKET_NOTICEBOARD_RESPONSE = 'CREATE_DA_OR_ID_SECONDARY_MARKET_NOTICEBOARD_RESPONSE'
    DELETE_SECONDARY_MARKET_NOTICEBOARD_ENTRY = 'DELETE_SECONDARY_MARKET_NOTICEBOARD_ENTRY'
    UPLOAD_LONG_TERM_BIDS = 'UPLOAD_LONG_TERM_BIDS'
    UPLOAD_DAY_AHEAD_OR_INTRA_DAY_BIDS = 'UPLOAD_DAY_AHEAD_OR_INTRA_DAY_BIDS'
    UPLOAD_TIMESCALE_NOMINATIONS = 'UPLOAD_TIMESCALE_NOMINATIONS'
    UPDATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOWS_BUSINESS_SETTINGS = 'UPDATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOWS_BUSINESS_SETTINGS'
    UPDATE_INTRA_DAY_NOMINATION_WINDOWS_BUSINESS_SETTINGS = 'UPDATE_INTRA_DAY_NOMINATION_WINDOWS_BUSINESS_SETTINGS'
    UPDATE_REALLOCATION_PRINCIPLES_BUSINESS_SETTINGS = 'UPDATE_REALLOCATION_PRINCIPLES_BUSINESS_SETTINGS'
    UPDATE_FINANCE_BUSINESS_SETTINGS = 'UPDATE_FINANCE_BUSINESS_SETTINGS'
    INIT_FINANCE_SAGE_AUTH = 'INIT_FINANCE_SAGE_AUTH'
    UPDATE_BPP_PROVIDER_BUSINESS_SETTINGS = 'UPDATE_BPP_PROVIDER_BUSINESS_SETTINGS'
    SEND_FINANCE_INVOICE = 'SEND_FINANCE_INVOICE'
    RESEND_FINANCE_INVOICE = 'RESEND_FINANCE_INVOICE'
    MARK_PAID_FINANCE_INVOICE = 'MARK_PAID_FINANCE_INVOICE'
    SUBMIT_FINANCE_MANUAL_ITEMS_INVOICE = 'SUBMIT_FINANCE_MANUAL_ITEMS_INVOICE'
    MANUAL_START_BUSINESS_PROCESS_WORKFLOW = 'MANUAL_START_BUSINESS_PROCESS_WORKFLOW'
    RESOLVE_BUSINESS_PROCESS_STEP = 'RESOLVE_BUSINESS_PROCESS_STEP'
    RE_RUN_BUSINESS_PROCESS_STEP = 'RE_RUN_BUSINESS_PROCESS_STEP'
    PROCESS_DATA_FLOW_VERSION = 'PROCESS_DATA_FLOW_VERSION'
    CREATE_DATA_FLOW = 'CREATE_DATA_FLOW'
    UPDATE_DATA_FLOW = 'UPDATE_DATA_FLOW'
    UPDATE_FINANCE_INFORMATION = 'UPDATE_FINANCE_INFORMATION'

    @classmethod
    def from_json(cls, json_str: str) -> AuditLogType:
        """Create an instance of AuditLogType from a JSON string"""
        return AuditLogType(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_inner_netted_nominations import ParticipantDashboardNettedNominationsDataMtusInnerNettedNominations  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestParticipantDashboardNettedNominationsDataMtusInnerNettedNominations(unittest.TestCase):
    """ParticipantDashboardNettedNominationsDataMtusInnerNettedNominations unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ParticipantDashboardNettedNominationsDataMtusInnerNettedNominations
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParticipantDashboardNettedNominationsDataMtusInnerNettedNominations`
        """
        model = empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_inner_netted_nominations.ParticipantDashboardNettedNominationsDataMtusInnerNettedNominations()  # noqa: E501
        if include_optional :
            return ParticipantDashboardNettedNominationsDataMtusInnerNettedNominations(
                flow = 56, 
                direction = 'GB_NL'
            )
        else :
            return ParticipantDashboardNettedNominationsDataMtusInnerNettedNominations(
                flow = 56,
                direction = 'GB_NL',
        )
        """

    def testParticipantDashboardNettedNominationsDataMtusInnerNettedNominations(self):
        """Test ParticipantDashboardNettedNominationsDataMtusInnerNettedNominations"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.participant_dashboard_next_auctions_and_nomination_gates import ParticipantDashboardNextAuctionsAndNominationGates  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestParticipantDashboardNextAuctionsAndNominationGates(unittest.TestCase):
    """ParticipantDashboardNextAuctionsAndNominationGates unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ParticipantDashboardNextAuctionsAndNominationGates
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParticipantDashboardNextAuctionsAndNominationGates`
        """
        model = empire_platform_api_public_client.models.participant_dashboard_next_auctions_and_nomination_gates.ParticipantDashboardNextAuctionsAndNominationGates()  # noqa: E501
        if include_optional :
            return ParticipantDashboardNextAuctionsAndNominationGates(
                nomination_gates = [
                    empire_platform_api_public_client.models.dashboard_next_nomination_gate.DashboardNextNominationGate(
                        timescale = 'LONG_TERM', 
                        window = empire_platform_api_public_client.models.dashboard_next_nomination_gate_window.DashboardNextNominationGate_window(
                            opens_at = '2022-01-04T00:00Z', 
                            closes_at = '2022-01-04T00:00Z', ), 
                        delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                            from_mtu_start = '2022-01-04T10:00Z', 
                            to_mtu_end = '2022-01-04T11:00Z', ), 
                        status = 'NOT_YET_OPEN', 
                        next_action_at = '2022-01-04T00:00Z', )
                    ], 
                day_ahead_auctions = [
                    empire_platform_api_public_client.models.participant_dashboard_next_auction.ParticipantDashboardNextAuction(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '2022 May Auction', 
                        delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                            from_mtu_start = '2022-01-04T10:00Z', 
                            to_mtu_end = '2022-01-04T11:00Z', ), 
                        product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                        border_direction = 'GB_NL', 
                        status = 'CREATED', 
                        pre_bidding_allowed = True, 
                        bids_count = 0, 
                        offered_capacity = 56, 
                        next_action_at = '2022-01-04T00:00Z', )
                    ], 
                intra_day_auctions = [
                    empire_platform_api_public_client.models.participant_dashboard_next_auction.ParticipantDashboardNextAuction(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '2022 May Auction', 
                        delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                            from_mtu_start = '2022-01-04T10:00Z', 
                            to_mtu_end = '2022-01-04T11:00Z', ), 
                        product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                        border_direction = 'GB_NL', 
                        status = 'CREATED', 
                        pre_bidding_allowed = True, 
                        bids_count = 0, 
                        offered_capacity = 56, 
                        next_action_at = '2022-01-04T00:00Z', )
                    ]
            )
        else :
            return ParticipantDashboardNextAuctionsAndNominationGates(
                nomination_gates = [
                    empire_platform_api_public_client.models.dashboard_next_nomination_gate.DashboardNextNominationGate(
                        timescale = 'LONG_TERM', 
                        window = empire_platform_api_public_client.models.dashboard_next_nomination_gate_window.DashboardNextNominationGate_window(
                            opens_at = '2022-01-04T00:00Z', 
                            closes_at = '2022-01-04T00:00Z', ), 
                        delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                            from_mtu_start = '2022-01-04T10:00Z', 
                            to_mtu_end = '2022-01-04T11:00Z', ), 
                        status = 'NOT_YET_OPEN', 
                        next_action_at = '2022-01-04T00:00Z', )
                    ],
                day_ahead_auctions = [
                    empire_platform_api_public_client.models.participant_dashboard_next_auction.ParticipantDashboardNextAuction(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '2022 May Auction', 
                        delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                            from_mtu_start = '2022-01-04T10:00Z', 
                            to_mtu_end = '2022-01-04T11:00Z', ), 
                        product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                        border_direction = 'GB_NL', 
                        status = 'CREATED', 
                        pre_bidding_allowed = True, 
                        bids_count = 0, 
                        offered_capacity = 56, 
                        next_action_at = '2022-01-04T00:00Z', )
                    ],
                intra_day_auctions = [
                    empire_platform_api_public_client.models.participant_dashboard_next_auction.ParticipantDashboardNextAuction(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '2022 May Auction', 
                        delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                            from_mtu_start = '2022-01-04T10:00Z', 
                            to_mtu_end = '2022-01-04T11:00Z', ), 
                        product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                        border_direction = 'GB_NL', 
                        status = 'CREATED', 
                        pre_bidding_allowed = True, 
                        bids_count = 0, 
                        offered_capacity = 56, 
                        next_action_at = '2022-01-04T00:00Z', )
                    ],
        )
        """

    def testParticipantDashboardNextAuctionsAndNominationGates(self):
        """Test ParticipantDashboardNextAuctionsAndNominationGates"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, conlist, constr, validator
from empire_platform_api_public_client.models.address import Address
from empire_platform_api_public_client.models.finance_information_bank_deposits_inner import FinanceInformationBankDepositsInner
from empire_platform_api_public_client.models.finance_information_letter_of_credits_inner import FinanceInformationLetterOfCreditsInner
from empire_platform_api_public_client.models.finance_information_market_vat_details import FinanceInformationMarketVatDetails
from empire_platform_api_public_client.models.finance_information_sage_settings import FinanceInformationSageSettings

class FinanceInformation(BaseModel):
    """
    FinanceInformation
    """
    sage_settings: Optional[FinanceInformationSageSettings] = Field(None, alias="sageSettings")
    billing_address: Optional[Address] = Field(None, alias="billingAddress")
    billing_email: Optional[constr(strict=True)] = Field(None, alias="billingEmail")
    vat_details: conlist(FinanceInformationMarketVatDetails) = Field(..., alias="vatDetails")
    letter_of_credits: conlist(FinanceInformationLetterOfCreditsInner) = Field(..., alias="letterOfCredits")
    bank_deposits: conlist(FinanceInformationBankDepositsInner) = Field(..., alias="bankDeposits")
    __properties = ["sageSettings", "billingAddress", "billingEmail", "vatDetails", "letterOfCredits", "bankDeposits"]

    # @validator('billing_email')
    def billing_email_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[\w-\.]+@([\w-]+\.)+[\w-]{2,6}$", value):
            raise ValueError(r"must validate the regular expression /^[\w-\.]+@([\w-]+\.)+[\w-]{2,6}$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FinanceInformation:
        """Create an instance of FinanceInformation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of sage_settings
        if self.sage_settings:
            _dict['sageSettings'] = self.sage_settings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of billing_address
        if self.billing_address:
            _dict['billingAddress'] = self.billing_address.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in vat_details (list)
        _items = []
        if self.vat_details:
            for _item in self.vat_details:
                if _item:
                    _items.append(_item.to_dict())
            _dict['vatDetails'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in letter_of_credits (list)
        _items = []
        if self.letter_of_credits:
            for _item in self.letter_of_credits:
                if _item:
                    _items.append(_item.to_dict())
            _dict['letterOfCredits'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in bank_deposits (list)
        _items = []
        if self.bank_deposits:
            for _item in self.bank_deposits:
                if _item:
                    _items.append(_item.to_dict())
            _dict['bankDeposits'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FinanceInformation:
        """Create an instance of FinanceInformation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FinanceInformation.parse_obj(obj)

        _obj = FinanceInformation.parse_obj({
            "sage_settings": FinanceInformationSageSettings.from_dict(obj.get("sageSettings")) if obj.get("sageSettings") is not None else None,
            "billing_address": Address.from_dict(obj.get("billingAddress")) if obj.get("billingAddress") is not None else None,
            "billing_email": obj.get("billingEmail"),
            "vat_details": [FinanceInformationMarketVatDetails.from_dict(_item) for _item in obj.get("vatDetails")] if obj.get("vatDetails") is not None else None,
            "letter_of_credits": [FinanceInformationLetterOfCreditsInner.from_dict(_item) for _item in obj.get("letterOfCredits")] if obj.get("letterOfCredits") is not None else None,
            "bank_deposits": [FinanceInformationBankDepositsInner.from_dict(_item) for _item in obj.get("bankDeposits")] if obj.get("bankDeposits") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr
from empire_platform_api_public_client.models.organisation_auth_method import OrganisationAuthMethod
from empire_platform_api_public_client.models.organisation_contact_information import OrganisationContactInformation
from empire_platform_api_public_client.models.organisation_file_settings import OrganisationFileSettings
from empire_platform_api_public_client.models.organisation_market_settings import OrganisationMarketSettings
from empire_platform_api_public_client.models.organisation_status import OrganisationStatus

class ParticipantOrganisationDetails(BaseModel):
    """
    ParticipantOrganisationDetails
    """
    id: StrictStr = Field(..., description="Unique identifier for the record in UUID4 format")
    status: OrganisationStatus = Field(...)
    name: StrictStr = Field(...)
    auth_method: OrganisationAuthMethod = Field(..., alias="authMethod")
    contact_information: OrganisationContactInformation = Field(..., alias="contactInformation")
    market_settings: OrganisationMarketSettings = Field(..., alias="marketSettings")
    file_settings: OrganisationFileSettings = Field(..., alias="fileSettings")
    __properties = ["id", "status", "name", "authMethod", "contactInformation", "marketSettings", "fileSettings"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParticipantOrganisationDetails:
        """Create an instance of ParticipantOrganisationDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of contact_information
        if self.contact_information:
            _dict['contactInformation'] = self.contact_information.to_dict()
        # override the default output from pydantic by calling `to_dict()` of market_settings
        if self.market_settings:
            _dict['marketSettings'] = self.market_settings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of file_settings
        if self.file_settings:
            _dict['fileSettings'] = self.file_settings.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParticipantOrganisationDetails:
        """Create an instance of ParticipantOrganisationDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ParticipantOrganisationDetails.parse_obj(obj)

        _obj = ParticipantOrganisationDetails.parse_obj({
            "id": obj.get("id"),
            "status": obj.get("status"),
            "name": obj.get("name"),
            "auth_method": obj.get("authMethod"),
            "contact_information": OrganisationContactInformation.from_dict(obj.get("contactInformation")) if obj.get("contactInformation") is not None else None,
            "market_settings": OrganisationMarketSettings.from_dict(obj.get("marketSettings")) if obj.get("marketSettings") is not None else None,
            "file_settings": OrganisationFileSettings.from_dict(obj.get("fileSettings")) if obj.get("fileSettings") is not None else None
        })
        return _obj

